<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="hr">
<context>
    <name>HomeDaemon</name>
    <message>
        <location filename="../src/main/homeDaemon.cpp" line="71"/>
        <source>Deepin Home</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/main/homeDaemon.cpp" line="83"/>
        <source>Show main window</source>
        <translation>Prikaži glavni prozor</translation>
    </message>
    <message>
        <location filename="../src/main/homeDaemon.cpp" line="89"/>
        <source>Communication</source>
        <translation>Komunikacija</translation>
    </message>
    <message>
        <location filename="../src/main/homeDaemon.cpp" line="92"/>
        <source>Exit</source>
        <translation>Izlaz</translation>
    </message>
    <message>
        <location filename="../src/main/homeDaemon.cpp" line="333"/>
        <source>View</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>